==> jc-1.4.0.tar.gz: java/nio/channels/UnsupportedAddressTypeException.h <==
// public class java.nio.channels.UnsupportedAddressTypeException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 680cf34d05feb5a1 java_lang_IllegalArgumentException
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class e6563bef14b5b3c java_nio_channels_UnsupportedAddressTypeException

// header file dependencies
// @dep_header java_lang_IllegalArgumentException

#include "java/lang/IllegalArgumentException.h"

#ifndef _JC_java_nio_channels_UnsupportedAddressTypeException_H_
#define _JC_java_nio_channels_UnsupportedAddressTypeException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_nio_channels_UnsupportedAddressTypeException$sub_refs	_jc_java_nio_channels_UnsupportedAddressTypeException$sub_refs;
typedef struct _jc_java_nio_channels_UnsupportedAddressTypeException$sub_nonrefs	_jc_java_nio_channels_UnsupportedAddressTypeException$sub_nonrefs;
typedef struct _jc_java_nio_channels_UnsupportedAddressTypeException$refs	_jc_java_nio_channels_UnsupportedAddressTypeException$refs;
typedef struct _jc_java_nio_channels_UnsupportedAddressTypeException$nonrefs	_jc_java_nio_channels_UnsupportedAddressTypeException$nonrefs;
typedef struct _jc_java_nio_channels_UnsupportedAddressTypeException$object	_jc_java_nio_channels_UnsupportedAddressTypeException$object;

typedef const struct _jc_java_nio_channels_UnsupportedAddressTypeException$vmethods	_jc_java_nio_channels_UnsupportedAddressTypeException$vmethods;
typedef const struct _jc_java_nio_channels_UnsupportedAddressTypeException$vtable	_jc_java_nio_channels_UnsupportedAddressTypeException$vtable;
typedef const struct _jc_java_nio_channels_UnsupportedAddressTypeException$vtype	_jc_java_nio_channels_UnsupportedAddressTypeException$vtype;

// Constructors
extern void _jc_java_nio_channels_UnsupportedAddressTypeException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_channels_UnsupportedAddressTypeException$object *);

// Virtual methods structure
struct _jc_java_nio_channels_UnsupportedAddressTypeException$vmethods {
};

// Vtable
struct _jc_java_nio_channels_UnsupportedAddressTypeException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_IllegalArgumentException$vmethods	java_lang_IllegalArgumentException;
	_jc_java_nio_channels_UnsupportedAddressTypeException$vmethods	java_nio_channels_UnsupportedAddressTypeException;
};

// Vtype
struct _jc_java_nio_channels_UnsupportedAddressTypeException$vtype {
	_jc_type			type;
	_jc_java_nio_channels_UnsupportedAddressTypeException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_channels_UnsupportedAddressTypeException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_channels_UnsupportedAddressTypeException$refs {
    _jc_java_nio_channels_UnsupportedAddressTypeException$sub_refs	java_nio_channels_UnsupportedAddressTypeException;
    _jc_java_lang_IllegalArgumentException$sub_refs	java_lang_IllegalArgumentException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_channels_UnsupportedAddressTypeException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_channels_UnsupportedAddressTypeException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_IllegalArgumentException$sub_nonrefs	java_lang_IllegalArgumentException;
    _jc_java_nio_channels_UnsupportedAddressTypeException$sub_nonrefs	java_nio_channels_UnsupportedAddressTypeException;
};

// Object instance structure
struct _jc_java_nio_channels_UnsupportedAddressTypeException$object {
	_jc_java_nio_channels_UnsupportedAddressTypeException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_channels_UnsupportedAddressTypeException$vtype	*vtype;
	_jc_java_nio_channels_UnsupportedAddressTypeException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_channels_UnsupportedAddressTypeException$vtype _jc_java_nio_channels_UnsupportedAddressTypeException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_channels_UnsupportedAddressTypeException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_channels_UnsupportedAddressTypeException$class_object;

#endif	/* _JC_java_nio_channels_UnsupportedAddressTypeException_H_ */

==> jc-1.4.6.tar.gz: java/nio/channels/UnsupportedAddressTypeException.h <==
// public class java.nio.channels.UnsupportedAddressTypeException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 680cf34d05feb5a1 java_lang_IllegalArgumentException
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class e6563bef14b5b3c java_nio_channels_UnsupportedAddressTypeException

// header file dependencies
// @dep_header java_lang_IllegalArgumentException

#include "java/lang/IllegalArgumentException.h"

#ifndef _JC_java_nio_channels_UnsupportedAddressTypeException_H_
#define _JC_java_nio_channels_UnsupportedAddressTypeException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_nio_channels_UnsupportedAddressTypeException$sub_refs	_jc_java_nio_channels_UnsupportedAddressTypeException$sub_refs;
typedef struct _jc_java_nio_channels_UnsupportedAddressTypeException$sub_nonrefs	_jc_java_nio_channels_UnsupportedAddressTypeException$sub_nonrefs;
typedef struct _jc_java_nio_channels_UnsupportedAddressTypeException$refs	_jc_java_nio_channels_UnsupportedAddressTypeException$refs;
typedef struct _jc_java_nio_channels_UnsupportedAddressTypeException$nonrefs	_jc_java_nio_channels_UnsupportedAddressTypeException$nonrefs;
typedef struct _jc_java_nio_channels_UnsupportedAddressTypeException$object	_jc_java_nio_channels_UnsupportedAddressTypeException$object;

typedef const struct _jc_java_nio_channels_UnsupportedAddressTypeException$vmethods	_jc_java_nio_channels_UnsupportedAddressTypeException$vmethods;
typedef const struct _jc_java_nio_channels_UnsupportedAddressTypeException$vtable	_jc_java_nio_channels_UnsupportedAddressTypeException$vtable;
typedef const struct _jc_java_nio_channels_UnsupportedAddressTypeException$vtype	_jc_java_nio_channels_UnsupportedAddressTypeException$vtype;

// Constructors
extern void _jc_java_nio_channels_UnsupportedAddressTypeException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_channels_UnsupportedAddressTypeException$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_nio_channels_UnsupportedAddressTypeException$vmethods {
};

// Vtable
struct _jc_java_nio_channels_UnsupportedAddressTypeException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_IllegalArgumentException$vmethods	java_lang_IllegalArgumentException;
	_jc_java_nio_channels_UnsupportedAddressTypeException$vmethods	java_nio_channels_UnsupportedAddressTypeException;
};

// Vtype
struct _jc_java_nio_channels_UnsupportedAddressTypeException$vtype {
	_jc_type			type;
	_jc_java_nio_channels_UnsupportedAddressTypeException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_channels_UnsupportedAddressTypeException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_channels_UnsupportedAddressTypeException$refs {
    _jc_java_nio_channels_UnsupportedAddressTypeException$sub_refs	java_nio_channels_UnsupportedAddressTypeException;
    _jc_java_lang_IllegalArgumentException$sub_refs	java_lang_IllegalArgumentException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_channels_UnsupportedAddressTypeException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_channels_UnsupportedAddressTypeException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_IllegalArgumentException$sub_nonrefs	java_lang_IllegalArgumentException;
    _jc_java_nio_channels_UnsupportedAddressTypeException$sub_nonrefs	java_nio_channels_UnsupportedAddressTypeException;
};

// Object instance structure
struct _jc_java_nio_channels_UnsupportedAddressTypeException$object {
	_jc_java_nio_channels_UnsupportedAddressTypeException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_channels_UnsupportedAddressTypeException$vtype	*vtype;
	_jc_java_nio_channels_UnsupportedAddressTypeException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_channels_UnsupportedAddressTypeException$vtype _jc_java_nio_channels_UnsupportedAddressTypeException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_channels_UnsupportedAddressTypeException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_channels_UnsupportedAddressTypeException$class_object;

#endif	/* _JC_java_nio_channels_UnsupportedAddressTypeException_H_ */
